@@ -22,7 +22,7 @@ class VideoInfo:
 
 
 class FFMPEG:
-    def __init__(self, verbose: bool, ffmpeg_location: str, encoder: str, audiocodec: str):
+    def __init__(self, verbose: bool, ffmpeg_location: str, encoder: str, audiocodec: str, preset: str):
         self.verbose = verbose
         self.ffmpeg_path = 'ffmpeg'
         self.ffprobe_path = 'ffprobe'
@@ -50,6 +50,7 @@ class FFMPEG:
 
         self.encoder = encoder
         self.audiocodec = audiocodec
+        self.preset = preset
         self.stderr_log = []
 
     def on_error(self, code: int):
@@ -179,7 +180,7 @@ class FFMPEG:
                 strict='experimental',
                 crf='22',
                 pix_fmt='yuv420p',
-                preset='ultrafast',
+                preset=self.preset,
             )
         )
         self.add_standard_handlers(ffmpeg)
@@ -204,7 +205,7 @@ class FFMPEG:
                     f'scale=w={width}:h={height}:force_original_aspect_ratio=decrease,'
                     + f'pad={width}:{height}:(ow-iw)/2:(oh-ih)/2'
                 ),
-                preset='fast',
+                preset=self.preset,
             )
         )
 
@@ -229,7 +230,7 @@ class FFMPEG:
                     'c:a': self.audiocodec,
                 },
                 strict='experimental',
-                preset='fast',
+                preset=self.preset,
             )
         )
         self.add_standard_handlers(ffmpeg)
@@ -277,7 +278,7 @@ class FFMPEG:
                     + '[ovrl];[1:v]fps=24,setpts=PTS-STARTPTS[bg];[bg][ovrl]overlay=W-w:H-h:shortest=1'
                 ),
                 strict='experimental',
-                preset='fast',
+                preset=self.preset,
             )
         )
         self.add_standard_handlers(ffmpeg)
@@ -298,7 +299,7 @@ class FFMPEG:
                 },
                 map=['0:a', '1:v'],
                 strict='experimental',
-                preset='fast',
+                preset=self.preset,
                 shortest=None,
             )
         )
